@@ -25,11 +25,10 @@ class SyncedCharacterAdmin(admin.ModelAdmin):
     actions = ["start_sync_contacts"]
     list_display_links = None
 
+    @admin.display(boolean=True)
     def _sync_ok(self, obj) -> bool:
         return obj.is_sync_ok
 
-    _sync_ok.boolean = True
-
     def has_add_permission(self, request):
         return False
 
@@ -39,16 +38,14 @@ class SyncedCharacterAdmin(admin.ModelAdmin):
     def character_name(self, obj):
         return obj.__str__()
 
+    @admin.display(description="Sync selected characters")
     def start_sync_contacts(self, request, queryset):
         names = list()
         for obj in queryset:
             tasks.run_character_sync.delay(sync_char_pk=obj.pk, force_sync=True)
             names.append(str(obj))
-
         self.message_user(request, "Started syncing for: {}".format(", ".join(names)))
 
-    start_sync_contacts.short_description = "Sync selected characters"
-
 
 @admin.register(SyncManager)
 class SyncManagerAdmin(admin.ModelAdmin):
@@ -66,11 +63,10 @@ class SyncManagerAdmin(admin.ModelAdmin):
     list_display_links = None
     actions = ["start_sync_managers"]
 
+    @admin.display(boolean=True)
     def _sync_ok(self, obj) -> bool:
         return obj.is_sync_ok
 
-    _sync_ok.boolean = True
-
     def has_add_permission(self, request):
         return False
 
@@ -89,13 +85,11 @@ class SyncManagerAdmin(admin.ModelAdmin):
     def synced_characters_count(self, obj):
         return "{:,}".format(obj.synced_characters.count())
 
+    @admin.display(description="Sync selected managers")
     def start_sync_managers(self, request, queryset):
         names = list()
         for obj in queryset:
             tasks.run_manager_sync.delay(manager_pk=obj.pk, force_sync=True)
             names.append(str(obj))
-
         text = "Started syncing for: {} ".format(", ".join(names))
         self.message_user(request, text)
-
-    start_sync_managers.short_description = "Sync selected managers"
